CREATE TABLE class_teachers (teacher_id bigint PRIMARY KEY AUTO_INCREMENT,
groupid bigint REFERENCES groups (groupid) ON DELETE CASCADE,
uid bigint REFERENCES users (uid) ON DELETE CASCADE,
linkid bigint REFERENCES groups_users_link (linkid) ON DELETE CASCADE
) DEFAULT CHARACTER SET utf8;

CREATE TABLE department_tbl (department_id int PRIMARY KEY AUTO_INCREMENT,
department_nam TEXT NOT NULL, comment TEXT)
DEFAULT CHARACTER SET utf8;

CREATE TABLE txt_level_tbl (txt_level_id int PRIMARY KEY AUTO_INCREMENT,
txt_level_nam TEXT NOT NULL, comment TEXT)
DEFAULT CHARACTER SET utf8;

CREATE TABLE difficulty_tbl (difficulty_id int PRIMARY KEY AUTO_INCREMENT,
difficulty_nam TEXT NOT NULL, comment TEXT)
DEFAULT CHARACTER SET utf8;

CREATE TABLE test_txt_tbl (text_id bigint PRIMARY KEY AUTO_INCREMENT, text_title text NOT NULL,
exp_dif int DEFAULT NULL,
real_dif int DEFAULT NULL,
level int DEFAULT NULL,
content text NOT NULL,
teacher_id bigint REFERENCES class_teachers (teacher_id) ON DELETE SET NULL, registered_date timestamp DEFAULT now(),
last_modifer_id bigint REFERENCES class_teachers (teacher_id) ON DELETE SET NULL,
last_modified_date timestamp,
department_id int DEFAULT NULL,
comment text,
av_file text,av_repeat int,
img_file text) DEFAULT CHARACTER SET utf8;

CREATE TABLE question_tbl (question_id bigint PRIMARY KEY AUTO_INCREMENT,
text_id bigint NOT NULL REFERENCES test_txt_tbl (text_id) ON DELETE CASCADE,
exp_dif int DEFAULT NULL,
real_dif int DEFAULT NULL,
level int DEFAULT NULL,
content text NOT NULL,
teacher_id bigint REFERENCES class_teachers (teacher_id) ON DELETE SET NULL,
registered_date timestamp DEFAULT now(),
last_modifer_id bigint REFERENCES class_teachers(teacher_id) ON DELETE SET NULL,
last_modified_date timestamp,
comment text,
answer int NOT NULL,
example text DEFAULT NULL,
rep_key character varying(20) DEFAULT '',
max_length int DEFAULT NULL,
max_words int DEFAULT NULL,
question_av_file text,
question_repeat int DEFAULT 1,
ave_percent int DEFAULT 0,
ave_sd float8,
public_falg CHAR(1) DEFAULT 0) DEFAULT CHARACTER SET utf8;

CREATE TABLE item_tbl (
question_id bigint NOT NULL REFERENCES question_tbl(question_id) ON DELETE CASCADE,
item_order character varying(4) NOT NULL,
item_txt text NOT NULL,
is_right int NOT NULL,
comment text,
CONSTRAINT item_tbl_pk PRIMARY KEY(question_id, item_order))
DEFAULT CHARACTER SET utf8;

CREATE TABLE template_tbl (template_id BIGINT PRIMARY KEY AUTO_INCREMENT,
template_name TEXT,
teacher_id bigint REFERENCES class_teachers(teacher_id) ON DELETE SET NULL, registered_date timestamp DEFAULT now(),
last_modifer_id bigint REFERENCES class_teachers(teacher_id) ON DELETE SET NULL, last_modified_date timestamp,sd_score float8,ave_score float8,participate_num int,
full_score int) DEFAULT CHARACTER SET utf8;

CREATE TABLE test_info_tbl (test_id bigint PRIMARY KEY AUTO_INCREMENT, test_nam character varying(50) NOT NULL,
teacher_id bigint REFERENCES class_teachers(teacher_id) ON DELETE SET NULL,
groupid bigint REFERENCES groups (groupid) ON DELETE CASCADE,
make_date timestamp NOT NULL DEFAULT now(),
test_date timestamp,
duration int DEFAULT 0,
exp_score float8 DEFAULT 0,real_score float8 DEFAULT 0,
status int NOT NULL DEFAULT 0,
partici_num int DEFAULT 0,sd_score float8 DEFAULT 0,
test_type smallint DEFAULT 0,
template_type bigint REFERENCES template_tbl (template_id) ON DELETE SET NULL,
full_score int) DEFAULT CHARACTER SET utf8;

CREATE TABLE tested_question_tbl (
tested_id bigint PRIMARY KEY AUTO_INCREMENT,
question_type bigint REFERENCES question_tbl (question_id) ON DELETE CASCADE,
test_id bigint REFERENCES test_info_tbl (test_id) ON DELETE CASCADE,
score int DEFAULT 0,
question_order int DEFAULT 0,
comment text,
ave_score float8 DEFAULT 0,
sddev float8 DEFAULT 0,
CONSTRAINT tested_question_tbl_uni UNIQUE(question_type, test_id)
) DEFAULT CHARACTER SET utf8;

CREATE TABLE class_student_tbl (
class_student_id int PRIMARY KEY AUTO_INCREMENT,
uid bigint REFERENCES users (uid) ON DELETE CASCADE,
groupid bigint REFERENCES groups (groupid) ON DELETE CASCADE,
student_comment text,
teacher_comment text,
present int DEFAULT 0,status int DEFAULT 0,
st_status int,
linkid bigint REFERENCES groups_users_link (linkid) ON DELETE CASCADE,
CONSTRAINT class_student_tbl_uni UNIQUE(uid, groupid))
DEFAULT CHARACTER SET utf8;

CREATE TABLE key_word_tbl (
key_word_id bigint PRIMARY KEY AUTO_INCREMENT,
question_id bigint NOT NULL REFERENCES question_tbl(question_id) ON DELETE CASCADE,
key_word_txt character varying(200) binary NOT NULL,
score_weight int NOT NULL DEFAULT 0,
comment text,
CONSTRAINT key_word_tbl_pk UNIQUE(question_id, key_word_txt))
DEFAULT CHARACTER SET utf8;

CREATE TABLE answered_item_tbl(
tested_id bigint REFERENCES tested_question_tbl (tested_id) ON DELETE CASCADE,
class_student_id int REFERENCES class_student_tbl (class_student_id) ON DELETE CASCADE,
answered_item character varying(4),
is_right int DEFAULT NULL,
CONSTRAINT answered_item_tbl_pk PRIMARY KEY(tested_id, class_student_id, answered_item))
DEFAULT CHARACTER SET utf8;

CREATE TABLE answered_txt_tbl(
tested_id bigint REFERENCES tested_question_tbl (tested_id) ON DELETE CASCADE,
class_student_id int REFERENCES class_student_tbl (class_student_id) ON DELETE CASCADE,
answered_txt text NOT NULL,
CONSTRAINT answered_txt_tbl_pk PRIMARY KEY(tested_id, class_student_id))
DEFAULT CHARACTER SET utf8;

CREATE TABLE student_test_tbl (
test_id bigint REFERENCES test_info_tbl (test_id) ON DELETE CASCADE,
class_student_id int REFERENCES class_student_tbl (class_student_id) ON DELETE CASCADE,
present int NOT NULL DEFAULT 0,
score int,
st_ts_comment text,
tea_ts_comment text,
sd_score float8 DEFAULT 0,
sd_score_temp float8 DEFAULT 0,
CONSTRAINT student_test_tbl_pk PRIMARY KEY(test_id, class_student_id))
DEFAULT CHARACTER SET utf8;

CREATE TABLE answered_score_tbl(
tested_id bigint REFERENCES tested_question_tbl (tested_id) ON DELETE CASCADE,
class_student_id int REFERENCES class_student_tbl (class_student_id) ON DELETE CASCADE,
score float8 DEFAULT NULL,sd_score float8 DEFAULT 0,
CONSTRAINT answered_score_tbl_pk PRIMARY KEY(tested_id, class_student_id))
DEFAULT CHARACTER SET utf8;

CREATE TABLE practice_tbl (
practice_id bigint PRIMARY KEY AUTO_INCREMENT,
practice_title text,
practice_text text,
cre_teacher_id bigint REFERENCES users (uid) ON DELETE SET NULL,
cre_student_id bigint REFERENCES users (uid) ON DELETE SET NULL,
img_file text, av_file text, level int,
department int REFERENCES department_tbl (department_id) ON DELETE SET NULL,
real_dif int,
exp_dif int,
answer int,
status int,
create_time datetime,
update_time datetime,
comment text,
parent_practice bigint REFERENCES practice_tbl (practice_id) ON DELETE SET NULL,
parent_question bigint REFERENCES question_tbl (question_id) ON DELETE SET NULL,
is_new int NOT NULL DEFAULT 1,
exp_dur int)
DEFAULT CHARACTER SET utf8;

CREATE TABLE practice_result_tbl (practice_result_id bigint PRIMARY KEY AUTO_INCREMENT,
usr_id bigint REFERENCES users (uid) ON DELETE CASCADE,
department_id int REFERENCES department_tbl (department_id) ON DELETE SET NULL,
practice_id bigint,
practice_time timestamp DEFAULT now(),
answered text,
is_right tinyint,
duration int)
DEFAULT CHARACTER SET utf8;

CREATE TABLE practice_item_tbl (
practice_id bigint NOT NULL REFERENCES practice_tbl (practice_id) ON DELETE CASCADE,
item_order character varying(4) NOT NULL,
item_txt text NOT NULL,
is_right int NOT NULL,
comment text,
CONSTRAINT item_tbl_practice_pk PRIMARY KEY(practice_id, item_order))
DEFAULT CHARACTER SET utf8;

CREATE TABLE practice_key_word_tbl (practice_key_word_id bigint PRIMARY KEY AUTO_INCREMENT,
practice_id bigint NOT NULL REFERENCES practice_tbl(practice_id) ON DELETE CASCADE,
key_word_txt character varying(200) binary NOT NULL,
score_weight int NOT NULL DEFAULT 0,
comment text,
CONSTRAINT key_word_tbl_practice_pk UNIQUE(practice_id, key_word_txt))
DEFAULT CHARACTER SET utf8;

CREATE TABLE practice_flag_tbl (practice_flag_id bigint PRIMARY KEY AUTO_INCREMENT,
usr_id bigint REFERENCES users (uid) ON DELETE CASCADE,
practice_id bigint NOT NULL REFERENCES practice_tbl(practice_id) ON DELETE CASCADE,
department_id int REFERENCES department_tbl (department_id) ON DELETE SET NULL
, CONSTRAINT practice_flg_tbl_pk UNIQUE(practice_id, usr_id)
)
DEFAULT CHARACTER SET utf8;

CREATE TABLE mobile_user_tbl (mobile_user_id bigint PRIMARY KEY AUTO_INCREMENT,
usr_id bigint REFERENCES users (uid) ON DELETE CASCADE,
mobile_id character varying(200) UNIQUE,
create_time datetime, update_time datetime
)
DEFAULT CHARACTER SET utf8;

CREATE TABLE practice_show_others_tbl(
practice_id bigint NOT NULL REFERENCES practice_tbl(practice_id) ON DELETE CASCADE,
usr_id bigint NOT NULL REFERENCES users(uid) ON DELETE CASCADE,
CONSTRAINT show_other_tbl_pk UNIQUE(practice_id, usr_id)
)
DEFAULT CHARACTER SET utf8;

CREATE TABLE prac_comment_tbl (prac_comment_id bigint PRIMARY KEY AUTO_INCREMENT,
prac_comment text,
usr_id bigint NOT NULL REFERENCES users (uid),
practice_id bigint NOT NULL REFERENCES practice_tbl(practice_id),
parent_comment_id bigint REFERENCES prac_comment_tbl(prac_comment_id),
positive int DEFAULT 0,
negative int DEFAULT 0,
create_time datetime,
uname text,
del_flag int DEFAULT 0)
DEFAULT CHARACTER SET utf8;

CREATE TABLE moshi_tbl (moshi_id bigint PRIMARY KEY AUTO_INCREMENT,
moshi_name text, moshi_com text,
student_id bigint DEFAULT NULL REFERENCES users (uid),
teacher_id bigint DEFAULT NULL REFERENCES users (uid),
difficulty int DEFAULT NULL REFERENCES difficulty_tbl (difficulty_id),
is_pub int DEFAULT 0,
create_time datetime,
update_time datetime,
duration int,
goal_score int,
is_new int DEFAULT 1,
moshi_type int,
disp_type int  DEFAULT 0,
select_ans_type bigint)
DEFAULT CHARACTER SET utf8;

CREATE TABLE  moshi_quiz_type_tbl (
moshi_quiz_type_id bigint PRIMARY KEY AUTO_INCREMENT,
score int,
number int,
type_com text,
is_middle int,
moshi_id bigint REFERENCES moshi_tbl (moshi_id) ON DELETE CASCADE,
department int REFERENCES department_tbl (department_id) ON DELETE SET NULL,
difficulty int REFERENCES difficulty_tbl (difficulty_id) ON DELETE SET NULL,
level int REFERENCES txt_level_tbl (txt_level_id) ON DELETE SET NULL
) DEFAULT CHARACTER SET utf8;

CREATE TABLE ansto_whole_moshi_tbl (
ansto_whole_moshi_id bigint PRIMARY KEY AUTO_INCREMENT,
moshi_id bigint REFERENCES moshi_tbl (moshi_id) ON DELETE SET NULL,
duration int,
score int,
uid bigint REFERENCES users (uid) ON DELETE SET NULL,
moshi_time datetime
) DEFAULT CHARACTER SET utf8;

CREATE TABLE ind_ansto_moshi_tbl (
ansto_whole_moshi_id bigint REFERENCES ansto_whole_moshi_tbl(ansto_whole_moshi_id) ON DELETE SET NULL,
practice_id bigint REFERENCES practice_tbl(practice_id) ON DELETE SET NULL,
moshi_quiz_type_id bigint REFERENCES moshi_quiz_type_tbl(moshi_quiz_type_id) ON DELETE SET NULL,
prac_result_id bigint REFERENCES practice_result_tbl(practice_result_id) ON DELETE SET NULL,
question_id bigint REFERENCES question_tbl (question_id) ON DELETE SET NULL,
answered text,
is_right int,
get_score int,
ans_order int,CONSTRAINT ansto_order UNIQUE (ansto_whole_moshi_id, ans_order),
CONSTRAINT ansto_prac UNIQUE (ansto_whole_moshi_id, prac_result_id)) DEFAULT CHARACTER SET utf8;

CREATE TABLE moshi_show_others_tbl (
moshi_id bigint REFERENCES moshi_tbl (moshi_id) ON DELETE CASCADE,
usr_id bigint REFERENCES users (uid) ON DELETE CASCADE
) DEFAULT CHARACTER SET utf8;

CREATE TABLE moshi_show_group_tbl (
moshi_id bigint REFERENCES moshi_tbl (moshi_id) ON DELETE CASCADE,
class_id bigint REFERENCES groups (groupid) ON DELETE CASCADE,
CONSTRAINT mc_link PRIMARY KEY (moshi_id, class_id)
) DEFAULT CHARACTER SET utf8;

CREATE TABLE eval_prac_tbl (
uid bigint REFERENCES users (uid) ,
practice_id bigint REFERENCES practice_tbl(practice_id),
eval int, createtime datetime,
CONSTRAINT upkey UNIQUE(uid, practice_id)) DEFAULT CHARACTER SET utf8;

CREATE TABLE eval_comment_tbl (
uid bigint REFERENCES users (uid) ,
prac_comment_id bigint REFERENCES prac_comment_tbl(prac_comment_id),
eval int, createtime datetime,
CONSTRAINT uckey UNIQUE(uid, prac_comment_id)) DEFAULT CHARACTER SET utf8;

CREATE TABLE rec_calc_status_tbl (
start_time datetime, end_time datetime,status int,
admin_id bigint REFERENCES users (uid),
reco_type int, include_peason int,
include_flag int, include_eval int) DEFAULT CHARACTER SET utf8;

CREATE TABLE flag_tanimoto_tbl (
tanimoto double,
uid1 bigint REFERENCES users (uid) ,
uid2 bigint REFERENCES users (uid) ,
create_time datetime) DEFAULT CHARACTER SET utf8;

CREATE TABLE eval_tanimoto_tbl (
tanimoto double,
uid1 bigint REFERENCES users (uid) ,
uid2 bigint REFERENCES users (uid) ,
create_time datetime) DEFAULT CHARACTER SET utf8;

CREATE TABLE incor_tmp_tbl (
percentage double,
uid bigint,
practice_id bigint,
INDEX uindex(uid), INDEX pracindex(practice_id)) DEFAULT CHARACTER SET utf8;

CREATE TABLE tmp_user_avg_tbl (uid bigint primary key,avg_score double) DEFAULT CHARACTER SET utf8;

CREATE TABLE tmp_prac_avg_tbl (practice_id bigint primary key,avg_score double) DEFAULT CHARACTER SET utf8;

CREATE TABLE pearson_user_tbl (
target1 bigint, target2 bigint, pearson_r double,
create_time datetime,
INDEX t1(target1), INDEX t2(target2)) DEFAULT CHARACTER SET utf8;

CREATE TABLE pearson_prac_tbl (
target1 bigint, target2 bigint, pearson_r double,
create_time datetime,
INDEX t1(target1), INDEX t2(target2)) DEFAULT CHARACTER SET utf8;

CREATE TABLE reco_prac_tbl (
uid bigint, practice_id bigint, relation double,
create_time datetime,
INDEX uidx(uid), INDEX pidx(practice_id)) DEFAULT CHARACTER SET utf8;

CREATE TABLE flag_prac_tanimoto_tbl (
tanimoto double,
practice_id1 bigint REFERENCES practice_tbl (practice_id) ,
practice_id2 bigint REFERENCES practice_tbl (practice_id) ,
create_time datetime
) DEFAULT CHARACTER SET utf8;

CREATE TABLE eval_prac_tanimoto_tbl (
tanimoto double,
practice_id1 bigint REFERENCES practice_tbl (practice_id) ,
practice_id2 bigint REFERENCES practice_tbl (practice_id) ,
create_time datetime
) DEFAULT CHARACTER SET utf8;

CREATE TABLE moshi_tea_permission_tbl (
moshi_id bigint REFERENCES moshi_tbl (moshi_id),
student_id bigint REFERENCES users (uid),
teacher_id bigint,
CONSTRAINT mtp_pk PRIMARY KEY (moshi_id, teacher_id,student_id)
) DEFAULT CHARACTER SET utf8;

CREATE TABLE moshi_comment_tbl (
moshi_comment_id bigint primary key AUTO_INCREMENT,
moshi_id bigint REFERENCES moshi_tbl (moshi_id),
student_id bigint REFERENCES users (uid),
teacher_id bigint REFERENCES users (uid),
moshi_comment text,
comment_time datetime,
already_read int,
is_tea int
) DEFAULT CHARACTER SET utf8;

CREATE TABLE moshi_perm_req_tbl (
moshi_id bigint REFERENCES moshi_tbl (moshi_id),
student_id bigint REFERENCES users (uid),
teacher_id bigint REFERENCES users (uid),
is_new int, 
create_time datetime,
CONSTRAINT moshi_perm_req_pk PRIMARY KEY (moshi_id, teacher_id,student_id)
) DEFAULT CHARACTER SET utf8;
